package appNodeInterface

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io"
	"net/http"
	"schedulerNode/log"
	"schedulerNode/models"
)

var client *http.Client

func init() {
	client = &http.Client{}
}

func SendSignallingInfo(ip, port string, req *models.SendSignallingReq) *models.AppNodeResponse {
	reqBody, err := json.Marshal(req)
	if err != nil {
		log.Error("json marshal  sendSignallingReq  failed ", err)
		return nil
	}
	url := fmt.Sprintf("http://%s:%s%s", ip, port, "/v1/connectSignalling")
	request, err := http.NewRequest("POST", url, bytes.NewReader(reqBody))
	if err != nil {
		log.Error("Error connectSignalling request ", err)
		return nil
	}
	resp, err := client.Do(request)
	if err != nil {
		log.Error("Error sending", err)
		return nil
	}
	appNodeResp := &models.AppNodeResponse{}
	respBody, err := io.ReadAll(resp.Body)
	if err != nil {
		log.Error("Error reading response body", err)
		return nil
	}
	err = json.Unmarshal(respBody, appNodeResp)
	if err != nil {
		log.Error("Unmarshal error: ", err)
		return nil
	}
	return appNodeResp
}

func GetSignallingConnectStatus(ip, port string) *models.SignallingConnectStatus {
	url := fmt.Sprintf("http://%s:%s%s", ip, port, "/v1/signalStatus")
	request, err := http.NewRequest("GET", url, nil)
	if err != nil {
		log.Error("GetSignallingConnectStatus Error new request: ", err)
		return nil
	}
	resp, err := client.Do(request)
	if err != nil {
		log.Error("GetSignallingConnectStatus send request error: ", err)
		return nil
	}
	respBody, err := io.ReadAll(resp.Body)
	if err != nil {
		log.Error("GetSignallingConnectStatus read resp body  error: ", err)
		return nil
	}
	res := &models.SignallingConnectStatus{}
	err = json.Unmarshal(respBody, &res)
	if err != nil {
		log.Error("GetSignallingConnectStatus json unmarshal error:", err)
		return nil
	}
	return res
}
